==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/6a/6acb050449a50b73b1577bdb8a4fbba9.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @JotaworksDoi/FormTheme/EmailSendList/emailsend_list_row.html.twig */
class __TwigTemplate_3c7b517f56305c1ad765d7507a25917b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<div class=\"row\">
    <div class=\"col-xs-";
        // line 2
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "email_type", [], "any", true, true, false, 2)) {
            yield "7";
        } else {
            yield "12";
        }
        yield "\">
        ";
        // line 3
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 3, $this->source); })()), "email", [], "any", false, false, false, 3), 'row');
        yield "
    </div>

    ";
        // line 6
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "email_type", [], "any", true, true, false, 6)) {
            // line 7
            yield "        <div class=\"col-xs-5\">
            ";
            // line 8
            yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 8, $this->source); })()), "email_type", [], "any", false, false, false, 8), 'row');
            yield "
        </div>
    ";
        }
        // line 11
        yield "
    ";
        // line 12
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "priority", [], "any", true, true, false, 12)) {
            // line 13
            yield "        <div id=\"priority\" class=\"col-xs-5 queue_hide\">
            ";
            // line 14
            yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 14, $this->source); })()), "priority", [], "any", false, false, false, 14), 'row');
            yield "
        </div>
    ";
        }
        // line 17
        yield "
    ";
        // line 18
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "attempts", [], "any", true, true, false, 18)) {
            // line 19
            yield "        <div id=\"attempts\" class=\"col-xs-5 queue_hide\">
            ";
            // line 20
            yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 20, $this->source); })()), "attempts", [], "any", false, false, false, 20), 'row');
            yield "
        </div>
    ";
        }
        // line 23
        yield "</div>

<div class=\"row\">
    <div class=\"col-xs-12 mt-lg\">
        <div class=\"mt-3\">
            ";
        // line 28
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 28, $this->source); })()), "newEmailButton", [], "any", false, false, false, 28), 'row');
        yield "
            ";
        // line 29
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 29, $this->source); })()), "editEmailButton", [], "any", false, false, false, 29), 'row');
        yield "
            ";
        // line 30
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 30, $this->source); })()), "previewEmailButton", [], "any", false, false, false, 30), 'row');
        yield "
        </div>
    </div>
</div>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@JotaworksDoi/FormTheme/EmailSendList/emailsend_list_row.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  113 => 30,  109 => 29,  105 => 28,  98 => 23,  92 => 20,  89 => 19,  87 => 18,  84 => 17,  78 => 14,  75 => 13,  73 => 12,  70 => 11,  64 => 8,  61 => 7,  59 => 6,  53 => 3,  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@JotaworksDoi/FormTheme/EmailSendList/emailsend_list_row.html.twig", "/var/www/mautic-ktn/plugins/JotaworksDoiBundle/Resources/views/FormTheme/EmailSendList/emailsend_list_row.html.twig");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/6a/6acb050449a50b73b1577bdb8a4fbba9.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @JotaworksDoi/FormTheme/EmailSendList/emailsend_list_row.html.twig */
class __TwigTemplate_3c7b517f56305c1ad765d7507a25917b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<div class=\"row\">
    <div class=\"col-xs-";
        // line 2
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "email_type", [], "any", true, true, false, 2)) {
            yield "7";
        } else {
            yield "12";
        }
        yield "\">
        ";
        // line 3
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 3, $this->source); })()), "email", [], "any", false, false, false, 3), 'row');
        yield "
    </div>

    ";
        // line 6
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "email_type", [], "any", true, true, false, 6)) {
            // line 7
            yield "        <div class=\"col-xs-5\">
            ";
            // line 8
            yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 8, $this->source); })()), "email_type", [], "any", false, false, false, 8), 'row');
            yield "
        </div>
    ";
        }
        // line 11
        yield "
    ";
        // line 12
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "priority", [], "any", true, true, false, 12)) {
            // line 13
            yield "        <div id=\"priority\" class=\"col-xs-5 queue_hide\">
            ";
            // line 14
            yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 14, $this->source); })()), "priority", [], "any", false, false, false, 14), 'row');
            yield "
        </div>
    ";
        }
        // line 17
        yield "
    ";
        // line 18
        if (CoreExtension::getAttribute($this->env, $this->source, ($context["form"] ?? null), "attempts", [], "any", true, true, false, 18)) {
            // line 19
            yield "        <div id=\"attempts\" class=\"col-xs-5 queue_hide\">
            ";
            // line 20
            yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 20, $this->source); })()), "attempts", [], "any", false, false, false, 20), 'row');
            yield "
        </div>
    ";
        }
        // line 23
        yield "</div>

<div class=\"row\">
    <div class=\"col-xs-12 mt-lg\">
        <div class=\"mt-3\">
            ";
        // line 28
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 28, $this->source); })()), "newEmailButton", [], "any", false, false, false, 28), 'row');
        yield "
            ";
        // line 29
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 29, $this->source); })()), "editEmailButton", [], "any", false, false, false, 29), 'row');
        yield "
            ";
        // line 30
        yield $this->env->getRuntime('Symfony\Component\Form\FormRenderer')->searchAndRenderBlock(CoreExtension::getAttribute($this->env, $this->source, (isset($context["form"]) || array_key_exists("form", $context) ? $context["form"] : (function () { throw new RuntimeError('Variable "form" does not exist.', 30, $this->source); })()), "previewEmailButton", [], "any", false, false, false, 30), 'row');
        yield "
        </div>
    </div>
</div>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@JotaworksDoi/FormTheme/EmailSendList/emailsend_list_row.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  113 => 30,  109 => 29,  105 => 28,  98 => 23,  92 => 20,  89 => 19,  87 => 18,  84 => 17,  78 => 14,  75 => 13,  73 => 12,  70 => 11,  64 => 8,  61 => 7,  59 => 6,  53 => 3,  45 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@JotaworksDoi/FormTheme/EmailSendList/emailsend_list_row.html.twig", "/var/www/html/mauticGIT-Test/plugins/JotaworksDoiBundle/Resources/views/FormTheme/EmailSendList/emailsend_list_row.html.twig");
    }
}
